@@ -31,7 +31,7 @@
 #include <Lum/Table.h>
 #include <Lum/Toggle.h>
 
-#include <Lum/OS/Manager/Repository.h>
+#include <Lum/Manager/Display.h>
 
 #include "Configuration.h"
 
@@ -69,7 +69,7 @@ void Countup::SetValue()
 
 void Countup::AllowScreenBlanking(bool allow)
 {
-  Lum::OS::Manager::DisplayManager *displayManager=Lum::OS::Manager::repository->GetDisplayManager();
+  Lum::Manager::Display *displayManager=Lum::Manager::Display::Instance();
 
   if (displayManager!=NULL) {
     displayManager->AllowScreenBlanking(allow);
@@ -160,7 +160,7 @@ void Countup::CalcSize()
   lapTable->SetModel(laps);
   lapTable->SetHeaderModel(headerModel);
   lapTable->SetShowHeader(false);
-  lapTable->GetTableView()->SetAutoHSize(true);
+  lapTable->SetAutoHSize(true);
 
   countdown=Lum::VPanel::Create(true,true)
             ->Add(Lum::HPanel::Create(true,true)
