@@ -18,7 +18,6 @@
 */
 
 #include <Lum/Base/L10N.h>
-#include <Lum/Base/Path.h>
 #include <Lum/Base/String.h>
 
 #include <Lum/Def/Menu.h>
@@ -29,12 +28,13 @@
 #include <Lum/Dlg/TimeSpanChooser.h>
 
 #include <Lum/Model/Action.h>
-#include <Lum/Model/Integer.h>
+#include <Lum/Model/Number.h>
 
-#include <Lum/OS/Main.h>
-
-#include <Lum/OS/Manager/Repository.h>
+#include <Lum/Manager/Behaviour.h>
+#include <Lum/Manager/Display.h>
+#include <Lum/Manager/FileSystem.h>
 
+#include <Lum/Application.h>
 #include <Lum/Button.h>
 #include <Lum/ButtonRow.h>
 #include <Lum/Dialog.h>
@@ -61,7 +61,7 @@ public:
   : prohibitScreenBlanking(new Lum::Model::Boolean(false)),
     aboutAction(new Lum::Model::Action())
   {
-    if (Lum::OS::Manager::repository->GetDisplayManager()==NULL) {
+    if (Lum::Manager::Display::Instance()==NULL) {
       prohibitScreenBlanking->Disable();
     }
 
@@ -113,7 +113,7 @@ public:
 
     multiView.SetMenu(preMenu,postMenu);
 
-    Lum::OS::display->GetBehaviour()->ApplyMultiViewDlg(this,multiView);
+    Lum::Manager::Behaviour::Instance()->ApplyMultiViewDlg(this,multiView);
 
     Dialog::PreInit();
   }
@@ -135,7 +135,7 @@ public:
       }
     }
     else if (model==prohibitScreenBlanking) {
-      Lum::OS::Manager::DisplayManager *displayManager=Lum::OS::Manager::repository->GetDisplayManager();
+      Lum::Manager::Display *displayManager=Lum::Manager::Display::Instance();
 
       if (displayManager!=NULL) {
         displayManager->AllowScreenBlanking(!prohibitScreenBlanking->Get());
@@ -150,13 +150,13 @@ public:
 
 };
 
-class Main : public Lum::OS::MainDialog<MainDialog>
+class Main : public Lum::GUIApplication<MainDialog>
 {
 public:
-  bool Prepare()
+  bool Initialize()
   {
 #if defined(APP_DATADIR)
-    Lum::Base::Path::SetApplicationDataDir(Lum::Base::StringToWString(APP_DATADIR));
+    Lum::Manager::FileSystem::Instance()->SetApplicationDataDir(Lum::Base::StringToWString(APP_DATADIR));
 #endif
 
     info.SetProgram(Lum::Base::StringToWString(PACKAGE_NAME));
@@ -167,12 +167,7 @@ public:
     info.SetCopyright(L"(c) 2009, Tim Teulings");
     info.SetLicense(L"GNU Public License");
 
-    return Lum::OS::MainDialog<MainDialog>::Prepare();
-  }
-
-  void Cleanup()
-  {
-    Lum::OS::MainDialog<MainDialog>::Cleanup();
+    return Lum::GUIApplication<MainDialog>::Initialize();
   }
 };
 
